Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetOracleConfig ¶
GetOracleConfig returns an Oracle connection config from environment variables
func SetupOracleConnection ¶
SetupOracleConnection creates a database connection without setting up tables
func SetupOracleTest ¶
SetupOracleTest creates a database connection and sets up test tables for Oracle
func SetupTestDB ¶
SetupTestDB creates a database connection and sets up test tables
func TeardownTestDB ¶
TeardownTestDB drops test tables and closes the connection
Types ¶
Click to show internal directories.
Click to hide internal directories.