Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CurrentAbsolutePath ¶
func CurrentAbsolutePath() string
CurrentAbsolutePath returns the current absolute path of the application.
func Is64Bit ¶
func Is64Bit() bool
Is64Bit returns whether the current CPU architecture is 64-bit. Is64Bit 返回当前 CPU 架构是否为 64 位。
func IsArm ¶
func IsArm() bool
IsArm returns whether the current CPU architecture is ARM. IsArm 返回当前 CPU 架构是否为 ARM。
func IsArtisan ¶
func IsArtisan() bool
IsArtisan checks if the application is running using artisan.
func IsDarwin ¶
func IsDarwin() bool
IsDarwin returns whether the current operating system is Darwin. IsDarwin 返回当前操作系统是否为 Darwin。
func IsDirectlyRun ¶
func IsDirectlyRun() bool
IsDirectlyRun checks if the application is running using go run .
func IsGithub ¶
func IsGithub() bool
IsGithub returns whether the current environment is github action. IsGithub 返回当前系统环境是否为 github action。
func IsLinux ¶
func IsLinux() bool
IsLinux returns whether the current operating system is Linux. IsLinux 返回当前操作系统是否为 Linux。
func IsTesting ¶
func IsTesting() bool
IsTesting checks if the application is running in testing mode.
Types ¶
This section is empty.